@@ -32,7 +32,7 @@
 *
 ***********************************************************************/
 
-#define VERSION "1.0.0"
+#define VERSION "1.0.1"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -374,6 +374,8 @@ askcmd (void)
  
    /* Position to the next field */
    nextfield();
+   if (output == stdout)
+      fflush (output);
  
    do
    {
@@ -400,6 +402,8 @@ askcmd (void)
 	 fputc ('\n', stdout);
          fflush (stdout);
 #endif
+	 if (output == stdout)
+	    pndx = PBEG;
  
          /* Read input */
          fgets (tbuf, sizeof (tbuf), stdin);
@@ -417,6 +421,8 @@ askcmd (void)
       {
          pcp++;
          fputc ('\n', stdout);
+	 if (output == stdout)
+	    pndx = PBEG;
       }
  
       /* check for prompt text */
@@ -721,16 +727,21 @@ erasecmd (void)
             getstp (stp);
             found = FALSE;
             if (!err_flag)
+            {
                while (q != NULL && !found)
                   if (!strcmp (q->grp_num, grp) &&
                       !strcmp (q->stp_num, stp))
+                  {
                      found = TRUE;
+                  }
                   else
                   {
                      q1 = q;
                      q = q->line_ptr;
                   }
+            }
             if (q != NULL)
+            {
                if (q != line_anchor)
                {
                   q1->line_ptr = q->line_ptr;
@@ -741,6 +752,7 @@ erasecmd (void)
                   line_anchor = q->line_ptr;
                   freeline (q);
                }
+            }
          }
  
          else
@@ -1042,7 +1054,7 @@ execline (void)
 	       {
 		  pndx = PBEG;
 		  pcp--;
-		  printf ("\npc = %08x, pcp = %08x\n", pc, pcp);
+		  printf ("\npc = %p, pcp =%p\n", pc, pcp);
 		  printf ("grp = %s, stp = %s\n", pc->grp_num, pc->stp_num);
 		  printf ("line = '%s'\n", pc->line_txt);
 		  printf ("%c(%02x): ", *pcp, *pcp);
@@ -1064,6 +1076,7 @@ execline (void)
  
       /* Check for loop in progress */
       if (pc_top != NULL)
+      {
          if (pc_top->pc_flags == FOR_FLG)
          {
             symboltable (for_top->for_index, &val, 0, TRUE);
@@ -1120,22 +1133,23 @@ execline (void)
                   do_mode = FALSE;
             }
          }
+      }
  
-         if ((run_mode || do_mode) && next)
+      if ((run_mode || do_mode) && next)
+      {
+         /* Point PC to next line */
+         p = pc->line_ptr;
+         if (p != NULL)
          {
-            /* Point PC to next line */
-            p = pc->line_ptr;
-            if (p != NULL)
+            pc = p;
+            pcp = pc->line_txt;
+            if (trace_flag)
             {
-               pc = p;
-               pcp = pc->line_txt;
-	       if (trace_flag)
-	       {
-		  fprintf (stdout, "\nN%s.%s ", pc->grp_num, pc->stp_num);
-	       }
+               fprintf (stdout, "\nN%s.%s ", pc->grp_num, pc->stp_num);
             }
-            else run_mode = FALSE;
          }
+         else run_mode = FALSE;
+      }
  
    } while (run_mode || pc_top != NULL);
  
@@ -1723,6 +1737,7 @@ insertline (void)
       /* Get line group number */
       getgrp (p->grp_num);
       if (!err_flag)
+      {
          if (*pcp == '.')
          {
             pcp++;
@@ -1834,13 +1849,13 @@ insertline (void)
                error (BAD_LINE, 0);
                freeline (p);
             }
+         }
+         else
+         {
+            error (BAD_LINE, 0);
+            freeline (p);
+         }
       }
-      else
-      {
-         error (BAD_LINE, 0);
-         freeline (p);
-      }
- 
    }
  
 } /* insertline */
@@ -2960,7 +2975,7 @@ main (int argc, char *argv[])
    }
 
    /* Print the banner */
-   printf ("FOCAL-%s execution begins\n", VERSION, stdout);
+   fprintf (stdout, "FOCAL-%s execution begins\n", VERSION);
 
    /* Process until quit command or EOF */
    while (!quit_flag)
